#
# spec file for package gsequencer
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define libagssonumber 1
%define libgsequencersonumber 0
Name:           gsequencer
Version:        1.4.31
Release:        lp151.2.44
Summary:        Audio processing engine
License:        GPL-3.0+ AND AGPL-3.0+ AND GFDL-1.3
Group:          Productivity/Multimedia/Sound/Midi
Url:            https://nongnu.org/gsequencer
Source0:        https://download.savannah.gnu.org/releases/gsequencer/1.4.x/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE gsequencer.0-fix-makefile-am.patch -- fix opensuse specific locations
Patch0:         gsequencer.0-fix-makefile-am.patch
BuildRequires:  cunit-devel
BuildRequires:  desktop-file-utils
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  dssi-devel
BuildRequires:  gettext-devel >= 0.19.8
BuildRequires:  gtk-doc
BuildRequires:  ladspa-cmt
BuildRequires:  ladspa-devel
BuildRequires:  libtool
BuildRequires:  lv2-devel
BuildRequires:  lv2-swh-plugins
BuildRequires:  pkgconfig
BuildRequires:  xvfb-run
BuildRequires:  pulseaudio
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libinstpatch-1.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(uuid)

%description
Advanced Gtk+ Sequencer is an audio
sequencer application supporting the LADPSA, DSSI and Lv2 plugin
formats. It can output to Pulseaudio server, JACK and ALSA.

You may add multiple sinks, mix different sources by producing
sound with different sequencers. Furthermore, it features a pattern
and piano roll and there is an editor to automate ports.

%prep
%setup -q
%patch0

%build
autoreconf -fi
export CPPFLAGS='-DAGS_RC_FILENAME=\"'%{_datadir}'/gsequencer/styles/ags.rc\" -DAGS_ANIMATION_FILENAME=\"'%{_datadir}'/gsequencer/images/ags_supermoon-800x450.png\" -DAGS_LOGO_FILENAME=\"'%{_datadir}'/gsequencer/images/ags.png\" -DAGS_LICENSE_FILENAME=\"'%{_datadir}'/licenses/gsequencer/COPYING\"'
%configure --disable-oss --enable-gtk-doc --enable-gtk-doc-html
%make_build all
%make_build html

%install
%make_install
%make_install install-html
find %{buildroot} -type f -name "*.la" -delete -print
rm -rf %{buildroot}%{_datadir}/doc-base/
mkdir -p %{buildroot}%{_datadir}/doc/packages
mv %{buildroot}%{_datadir}/doc/gsequencer  %{buildroot}%{_docdir}

%check
xvfb-run --server-args="-screen 0 1920x1080x24" -a make check
desktop-file-validate %{buildroot}/%{_datadir}/applications/gsequencer.desktop

%files
%license COPYING
%{_bindir}/gsequencer
%{_bindir}/midi2xml
%{_mandir}/man1/gsequencer.1*
%{_mandir}/man1/midi2xml.1*
%{_datadir}/gsequencer/
%{_datadir}/xml/gsequencer/
%{_docdir}/gsequencer/
%{_datadir}/applications/gsequencer.desktop

%package -n libags%{libagssonumber}
Summary:        GSequencer core libraries
Group:          System/Libraries

%description -n libags%{libagssonumber}
Advanced Gtk+ Sequencer is an audio sequencer application.
This subpackage contains part of its library set.

%package -n libgsequencer%{libgsequencersonumber}
Summary:        GSequencer core libraries
Group:          System/Libraries

%description -n libgsequencer%{libgsequencersonumber}
Advanced Gtk+ Sequencer is an audio sequencer application.
This subpackage contains part of its library set.

%package devel
Summary:        Advanced Gtk+ Sequencer library development files
Group:          Development/Libraries/C and C++
Requires:       libags%{libagssonumber} = %{version}
Requires:       libgsequencer%{libgsequencersonumber} = %{version}

%description devel
Advanced Gtk+ Sequencer library development files.

%files devel
%{_includedir}/ags/
%{_libdir}/libags.so
%{_libdir}/libags_thread.so
%{_libdir}/libags_server.so
%{_libdir}/libags_gui.so
%{_libdir}/libags_audio.so
%{_libdir}/libgsequencer.so
%{_libdir}/pkgconfig/libags.pc
%{_libdir}/pkgconfig/libags_audio.pc
%{_libdir}/pkgconfig/libags_gui.pc
%{_libdir}/pkgconfig/libgsequencer.pc

%package -n gsequencer-devel-doc
Summary:        Documentation for Advanced Gtk+ Sequencer
Group:          Documentation/HTML
BuildArch:      noarch

%description -n gsequencer-devel-doc
Advanced Gtk+ Sequencer library development documentation.

%post   -n libags%{libagssonumber} -p /sbin/ldconfig
%postun -n libags%{libagssonumber} -p /sbin/ldconfig
%post   -n libgsequencer%{libgsequencersonumber} -p /sbin/ldconfig
%postun -n libgsequencer%{libgsequencersonumber} -p /sbin/ldconfig

%files -n libags%{libagssonumber}
%defattr(-,root,root)
%{_libdir}/libags.so.%{libagssonumber}*
%{_libdir}/libags_thread.so.%{libagssonumber}*
%{_libdir}/libags_server.so.%{libagssonumber}*
%{_libdir}/libags_gui.so.%{libagssonumber}*
%{_libdir}/libags_audio.so.%{libagssonumber}*

%files -n libgsequencer%{libgsequencersonumber}
%defattr(-,root,root)
%{_libdir}/libgsequencer.so.%{libgsequencersonumber}*

%files -n gsequencer-devel-doc
%{_datadir}/gtk-doc/
%{_datadir}/doc/libags-audio-doc/

%changelog
* Fri May 11 2018 jkraehemann@gmail.com
- new upstream v1.4.31 fixed muted DSSI and possible SIGSEGV as
  relink line after destroyed machine.
* Tue May  8 2018 jkraehemann@gmail.com
- new upstream v1.4.29 fixed missing timestamp check against lower
  bounds in if statement.
* Sun May  6 2018 jkraehemann@gmail.com
- New upstream v1.4.28 fixed selection of notation and automation
  editor. Minor improvements to lv2 and editor clipboard.
* Wed Apr 11 2018 jkraehemann@gmail.com
- New upstream v1.4.25 fixed memory corruption related to writing
  of pointer to struct of different allocation. Exported missing
  symbol of ags_widget_marshal.h and fixed an event doing potential
  infinite loop.
* Mon Mar 26 2018 jkraehemann@gmail.com
- New upstream v1.4.24 minor improvements. Refactored startup
  process and improved thread-safety.
* Sun Mar 11 2018 jkraehemann@gmail.com
- New upstream v1.4.21 reverted the use of GMainLoop for pulseaudio
  because of a race-condition. Faster lv2 plugin loading.
* Sat Feb  3 2018 jkraehemann@gmail.com
- New upstream v1.4.18 fixed step sequencer's clipboard.
* Fri Feb  2 2018 jkraehemann@gmail.com
- New upstream v1.4.17 various fixes to initialization code of
  recalls in ags_channel.c.
- Fixed playback scope and related code in ags_play_channel_run.c.
* Mon Jan 29 2018 jkraehemann@gmail.com
- Removed libpulse-mainloop-glib0 because it is already provided.
* Sun Jan 28 2018 jkraehemann@gmail.com
- New upstream v1.4.15 replaced pa_main_loop_new() by
  pa_glib_main_loop_new().
- Added libpulse-mainloop-glib0 dependency to spec.
* Mon Jan 22 2018 jkraehemann@gmail.com
- New upstream v1.4.14 important fixes to ags_simple_file.c causing
  SIGSEGV during restore of files containing pattern data.
- Implemented rt-safe mode without any dynamic memory allocation
  from audio processing threads during playback.
- Minor-fixes.
* Tue Jan  9 2018 jkraehemann@gmail.com
- new upstream v1.3.6 fixes the most annoying bug ever. The
  "clipping" issue of GtkPaned was solved by a GtkViewport.
* Mon Jan  8 2018 jkraehemann@gmail.com
- new upstream v1.3.5 minor fixes, increased functional test's
  timeout in order to run more reliable on low power systems.
* Mon Jan  8 2018 jkraehemann@gmail.com
- new upstream v1.3.4 fixes to the notation and automation editor.
  It is considered to be important to update. Since unexpected
  behaviour can occur.
* Sat Jan  6 2018 jkraehemann@gmail.com
- new upstream v1.3.3 various bug-fixes including fix of ags.rc
  theme, memory-leaks and buffer-overflow.
* Fri Jan  5 2018 jkraehemann@gmail.com
- new upstream v1.3.1 minor bug-fixes and ags.rc improvements
* Fri Jan  5 2018 jkraehemann@gmail.com
- new upstream v1.3.0 refactored AgsAutomationEditor, make code
  more intuitive and added new widgets.
- Supporting 4 different paste modes, switches are match audio
  channel/line or no-duplicates.
* Sun Dec 24 2017 jkraehemann@gmail.com
- new upstream v1.2.7 refactored big parts of ags_channel.c, make
  code reusable and strip redundant code as well being thread-safe.
* Fri Dec 22 2017 jkraehemann@gmail.com
- added pulseaudio as dependency of tests
* Fri Dec 22 2017 jkraehemann@gmail.com
- new upstream v1.2.5 fixed unitialized pointer
* Thu Dec 21 2017 jkraehemann@gmail.com
- new upstream v1.2.4 minor fixes
* Thu Dec 21 2017 jkraehemann@gmail.com
- new upstream v1.2.3 minor fixes and rollback of 3 functions
- removed gsequencer.1-fix-libgsequencer-xml.patch because applied
  upstream
* Thu Dec 21 2017 jkraehemann@gmail.com
- new upstream v1.2.2 refactored direct callbacks to UI to async
  message delivery.
- extended libags-audio.so.1 API
- provide Patch1 to fix broken libgsequencer API reference manual
* Fri Dec  8 2017 jkraehemann@gmail.com
- new upstream v1.1.6 fixing unitialized pointers of GtkStyle
- removed libgmp-devel dependency because it is not needed
* Sat Nov 25 2017 jkraehemann@gmail.com
- new upstream v1.1.5 providing minor improvements
* Thu Nov  2 2017 jkraehemann@gmail.com
- edited spec to ensure sonumber
* Thu Nov  2 2017 jkraehemann@gmail.com
- added Group to main package
* Wed Oct 18 2017 alarrosa@suse.com
- Define libagssonumber and libgsequencersonumber in the spec file
  so we are sure the library sonumbers match the package names
* Tue Oct 17 2017 jkraehemann@gmail.com
- removed rpath changes in gsequencer.spec
- added minimal comment about opensuse specific Patch0
* Sun Oct 15 2017 jkraehemann@gmail.com
- update to package gsequencer-1.1.4
* Sun Oct  8 2017 jkraehemann@gmail.com
- update to package gsequencer-1.0.4
- update gsequencer.0-makefile-am.patch
* Sat Oct  7 2017 jkraehemann@gmail.com
- update to package gsequencer-1.0.3
- micro fixes
* Sat Oct  7 2017 jkraehemann@gmail.com
- update to package gsequencer-1.0.2
- provide merged patches by gsequencer.0-fix-makefile-am.patch
- removed gsequencer.3-fix-libgsequencer-doc.patch because applied
  upstream
- removed gsequencer.4-fix-return-value.patch because applied
  upstream
- removed gseqeuencer.0-fix-docbook-path.patch because merged
- removed gsequencer.1-fix-libgsequencer-blue-print.patch because
  merged
- removed gsequencer.2-fix-gtk-doc.patch because merged
* Fri Oct  6 2017 jengelh@inai.de
- Implement shared library guideline.
  Remove duplicate wording in descriptions.
* Mon Oct  2 2017 jkraehemann@gmail.com
- update to package gsequencer-1.0.0
  * Providing fixed LV2UI support. Set default value of controls,
    sync gsequencer provided plugin UI with plugin's own UI. Proper
    destruction of plugin UI by idle return value and or by
    application semantics.
  * Provide base-frequency configuration option in performance tab
    of preferences dialog. This configuration switch modifies the
    base synchronization rate of threads. By default 125, 250 and
    1000 Hz is provided. Note by using smaller buffer-size you might
    have to increase the base-frequency.
  * Implemented sticky controls, allowing you modify controls of
    grouped channels in one step.
  * Minor fixes and improvements.
  * Removed AgsMidiFileWriter and AgsMidiFileReader, please use
    AgsMidiBuilder or AgsMidiParser instead.
  * Added many prototypes of libags_server.so.1 and extended
    AgsServiceProvider interface.
  * Added AgsUiProvider interface.
- modified Source0 to point to new upstream directory
- added AGPL-3.0+ to license field since libags_server.so.1 uses it
- removed gsequencer.3-add-no-undefined.patch because applied
  upstream
- removed gsequencer.4-fix-test-arg.patch because applied upstream
- removed gsequencer.5-fix-turtle.patch because applied upstream
- provide gsequencer.3-fix-libgsequencer-doc.patch to fix missing
  types
- provide gsequencer.4-fix-return-value.patch to fix missing return
* Sun Sep 24 2017 jkraehemann@gmail.com
- update to package gsequencer-0.9.28
- removed gsequencer.3-fix-missing-return.patch because applied
  upstream
- enabled `make check` to run unit and functional tests
- provide gsequencer.3-add-no-undefined.patch to fix *_LDFLAGS and
  an issue with $(top_srcdir)
- provide gsequencer.4-fix-test-arg.patch to fix writing to
  excessed array index
- provide gsequencer.5-fix-turtle.patch to fix reading excessed
  array index
* Sat Sep 16 2017 jkraehemann@gmail.com
- update to package gsequencer-0.9.25
- moved fix gtk doc patch to gsequencer.2-fix-gtk-doc.patch
- provide patch gsequencer.3-fix-missing-return.patch
- modified gsequencer.spec to use macros to specify filenames
* Mon Aug 28 2017 jkraehemann@gmail.com
- update to package gsequencer-0.9.22
* Sun Aug 27 2017 jkraehemann@gmail.com
- update to package gsequencer-0.9.21
* Sun Aug 27 2017 jkraehemann@gmail.com
- update to package gsequencer-0.9.20
- updated gsequencer.3-fix-gtk-doc.patch
- removed gsequencer.4-fix-desktop-category.patch
- removed gsequencer.5-fix-missing-xml.patch
* Sat Aug 26 2017 jkraehemann@gmail.com
- update to package gsequencer-0.9.16
- updated gsequencer.4-fix-desktop-category.patch because upstream
  changed icon
- updated gsequencer.2-fix-license-and-logo.patch because upstream
  refactoring callback providing in view of providing a popup menu
- updated gsequencer.3-fix-gtk-doc.patch because upstream improved
  the makefile target
- removed gsequencer.5-fix-missing-include.patch because applied
  upstream
- provide patch gsequencer.5-disable-missing-xml.patch
* Tue Aug 22 2017 jkraehemann@gmail.com
- update to package gsequencer-0.9.14
- provide patch gsequencer.5-fix-missing-include.patch
* Tue Aug 22 2017 jkraehemann@gmail.com
- new upstream package containing bug-fixes and pulseaudio support
* Sat Aug  5 2017 jkraehemann@gmail.com
- initial upstream package
- provide patch gsequencer.0-fix-docbook-path.patch
- provide patch gsequencer.1-fix-libgsequencer-blue-print.patch
- provide patch gsequencer.3-fix-license-and-logo.patch
- provide patch gsequencer.4-fix-desktop-category.patch
